@@ -18,7 +18,7 @@ You should have received a copy of the GNU Lesser General Public
 License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 // Qt
-#include <QtTest/QtTest>
+#include <QtTest>
 // WaylandServer
 #include "../../src/server/display.h"
 #include "../../src/server/clientconnection.h"
@@ -43,6 +43,7 @@ private Q_SLOTS:
     void testClientConnection();
     void testConnectNoSocket();
     void testOutputManagement();
+    void testAutoSocketName();
 };
 
 void TestWaylandServerDisplay::testSocketName()
@@ -207,14 +208,37 @@ void TestWaylandServerDisplay::testConnectNoSocket()
 
 void TestWaylandServerDisplay::testOutputManagement()
 {
-    auto display = new KWayland::Server::Display(this);
-    display->setSocketName("kwayland-test-0");
-    display->start();
-    auto kwin = display->createOutputManagement(this);
+    Display display;
+    display.setSocketName("kwayland-test-0");
+    display.start();
+    auto kwin = display.createOutputManagement(this);
     kwin->create();
     QVERIFY(kwin->isValid());
 }
 
+void TestWaylandServerDisplay::testAutoSocketName()
+{
+    QTemporaryDir runtimeDir;
+    QVERIFY(runtimeDir.isValid());
+    QVERIFY(qputenv("XDG_RUNTIME_DIR", runtimeDir.path().toUtf8()));
+
+    Display display0;
+    display0.setAutomaticSocketNaming(true);
+    QSignalSpy socketNameChangedSpy0(&display0, SIGNAL(socketNameChanged(QString)));
+    display0.start();
+    QVERIFY(display0.isRunning());
+    QCOMPARE(socketNameChangedSpy0.count(), 0);
+    QCOMPARE(display0.socketName(), QStringLiteral("wayland-0"));
+
+    Display display1;
+    display1.setAutomaticSocketNaming(true);
+    QSignalSpy socketNameChangedSpy1(&display1, SIGNAL(socketNameChanged(QString)));
+    display1.start();
+    QVERIFY(display1.isRunning());
+    QCOMPARE(socketNameChangedSpy1.count(), 1);
+    QCOMPARE(display1.socketName(), QStringLiteral("wayland-1"));
+}
+
 
 QTEST_GUILESS_MAIN(TestWaylandServerDisplay)
 #include "test_display.moc"
